@@ -4,6 +4,7 @@ module Doorkeeper
 
     include OAuth::Helpers
     include Models::Scopes
+    include ActiveModel::MassAssignmentSecurity if defined?(::ProtectedAttributes)
 
     included do
       has_many :access_grants, dependent: :destroy, class_name: 'Doorkeeper::AccessGrant'
@@ -15,8 +16,8 @@ module Doorkeeper
 
       before_validation :generate_uid, :generate_secret, on: :create
 
-      if ::Rails.version.to_i < 4 || defined?(::ProtectedAttributes)
-        attr_accessible :name, :redirect_uri
+      if respond_to?(:attr_accessible)
+        attr_accessible :name, :redirect_uri, :scopes
       end
     end
 
@@ -30,18 +31,6 @@ module Doorkeeper
       end
     end
 
-    alias_method :original_scopes, :scopes
-    def scopes
-      if has_scopes?
-        original_scopes
-      else
-        fail NameError, "Missing column: `applications.scopes`.", <<-MSG.squish
-If you are using ActiveRecord run `rails generate doorkeeper:application_scopes
-&& rake db:migrate` to add it.
-        MSG
-      end
-    end
-
     private
 
     def has_scopes?
@@ -50,11 +39,15 @@ If you are using ActiveRecord run `rails generate doorkeeper:application_scopes
     end
 
     def generate_uid
-      self.uid ||= UniqueToken.generate
+      if uid.blank?
+        self.uid = UniqueToken.generate
+      end
     end
 
     def generate_secret
-      self.secret ||= UniqueToken.generate
+      if secret.blank?
+        self.secret = UniqueToken.generate
+      end
     end
   end
 end
